==> rivendell-1.0.0rc1.tar.gz: rivendell-1.0.0rc1/utils/rddbcheck/rddbcheck.h <==
// rddbcheck.h
//
// A Database Check/Repair Tool for Rivendell.
//
//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
//
//      $Id: rddbcheck.h,v 1.4 2008/02/27 21:57:32 fredg Exp $
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License version 2 as
//   published by the Free Software Foundation.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//


#ifndef RDDBCHECK_H
#define RDDBCHECK_H

#include <list>

#include <qobject.h>
#include <qsqldatabase.h>

#include <rdconfig.h>
#include <rdcmd_switch.cpp>

#define RDDBCHECK_USAGE "[--yes|--no]\n\nCheck the Rivendell database and audio store for consistency\nand correctness.\n\n   --yes     Answer all questions with 'yes'\n\n   --no      Answer all questions with 'no'\n"

//
// Global Variables
//
RDConfig *rdconfig;


class MainObject : public QObject
{
 public:
  MainObject(QObject *parent=0,const char *name=0);

 private:
  void CheckOrphanedTracks();
  void CheckClocks();
  void CheckEvents();
  bool UserResponse();
  bool check_yes;
  bool check_no;
};


#endif  // RDDBCHECK_H

==> rivendell-1.2.0.tar.gz: rivendell-1.2.0/utils/rddbcheck/rddbcheck.h <==
// rddbcheck.h
//
// A Database Check/Repair Tool for Rivendell.
//
//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
//
//      $Id: rddbcheck.h,v 1.5 2008-06-24 22:17:49 fredg Exp $
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License version 2 as
//   published by the Free Software Foundation.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//


#ifndef RDDBCHECK_H
#define RDDBCHECK_H

#include <list>

#include <qobject.h>
#include <qsqldatabase.h>

#include <rdconfig.h>
#include <rdcmd_switch.cpp>

#define RDDBCHECK_USAGE "[--yes|--no]\n\nCheck the Rivendell database and audio store for consistency\nand correctness.\n\n   --yes     Answer all questions with 'yes'\n\n   --no      Answer all questions with 'no'\n"

//
// Global Variables
//
RDConfig *rdconfig;


class MainObject : public QObject
{
 public:
  MainObject(QObject *parent=0,const char *name=0);

 private:
  void CheckOrphanedTracks();
  void CheckClocks();
  void CheckEvents();
  void CheckOrphanedTables();
  void CleanTables(const QString &ext,QSqlQuery *table_q,QSqlQuery *name_q);
  void CleanTables(const QString &ext,QSqlQuery *table_q);
  bool IsTableLinked(QSqlQuery *name_q,const QString &ext,const QString &table);
  bool UserResponse();
  bool check_yes;
  bool check_no;
};


#endif  // RDDBCHECK_H
